%Appendix B
%The Matlab6.0 code of High Dynamic Range image
%display using Level Set method proposed in this
%paper is given below.

function [ ]=lsHDRC(filename, nsteps)
	%%%set up parameters
	delt = 0.15; % t D
	%nsteps = 15; % recommended
	sensitivity = 8.0; %sen, for edge sensitivity
	vision = 0.73; % for vision, the smaller, the more
	% accurate of the vision
	CIE_rf=.265074126; CIE_gr=.670114631;
	CIE_br=.064811243; MIN_LUM = 1.0e-3;
	%	PAGE BREAK ================================================================
	%%%Read in the luminance image and store in r, g, b
	[r g b]=rgbereadrgb(rgbefilename);
	%%%Get luminance value
	im = CIE_rf*r + CIE_gr*g + CIE_br*b;
	im(find(im==0))=MIN_LUM;
	%%% transform luminance into logarithm domain.
	loglum = log(im);
	%%% extract profile using LS =>prologlum
	prologlum = imgmanf(loglum,delt,nsteps,nnsteps,sensitivity);
	meanlum = exp(median(loglum(:)));
	n = vision;
	factor = exp(prologlum).^(n-1) ./(exp(prologlum).^n + (meanlum/0.18)^n);
	%%%recover low dynamic range image =>r,g,b
	r = r .*factor; g = g .*factor; b = b .*factor;
	%%%show compressed image
	tiffwrite(r,g,b,lhrfilename);
%%%OK